Enum Cms
#[repr(u8)]pub enum Cms {
EdgeAligned = 0,
CenterAligned1 = 1,
CenterAligned2 = 2,
CenterAligned3 = 3,
}Variants
EdgeAligned = 0
The counter counts up or down depending on the direction bit
CenterAligned1 = 1
The counter counts up and down alternatively. Output compare interrupt flags are set only when the counter is counting down.
CenterAligned2 = 2
The counter counts up and down alternatively. Output compare interrupt flags are set only when the counter is counting up.
CenterAligned3 = 3
The counter counts up and down alternatively. Output compare interrupt flags are set both when the counter is counting up or down.
Implementations